# ninstd
A wrapper of Python using only standard libraries. <br>
The goad of the module is to provide a basic support for my future modules. <br>
`ninstd` includes any type of applications.

## To install
```
pip install ninstd
```

## Directory tree
```
ninstd_____error
	|__check
	|__path
	|__recorder
	|__utils
	|__typing
```

## License
MIT License with some exceptions. <br>
Please look at comments within the module.


## TODO
- Type hinting.
- Make it loadable.
